/// <reference types="react" />
import * as react from 'react';
import react__default, { PropsWithChildren, ComponentProps, HTMLAttributes } from 'react';
import * as _tanstack_react_query from '@tanstack/react-query';
import { QueryClient, UseQueryResult } from '@tanstack/react-query';
import * as valibot from 'valibot';
import { Output } from 'valibot';
import * as _material_ui_core from '@material-ui/core';
import * as _backstage_core_plugin_api from '@backstage/core-plugin-api';

type CoderAuthProviderProps = Readonly<PropsWithChildren<unknown>>;
declare const CoderAuthProvider: ({ children }: CoderAuthProviderProps) => react__default.JSX.Element;

type CoderAppConfig = Readonly<{
    deployment: Readonly<{
        accessUrl: string;
    }>;
    workspaces: Readonly<{
        defaultMode?: WorkspaceCreationMode;
        defaultTemplateName?: string;
        params?: Record<string, string | undefined>;
        repoUrlParamKeys: readonly [string, ...string[]];
    }>;
}>;
type CoderSettingsProviderProps = Readonly<PropsWithChildren<{
    appConfig: CoderAppConfig;
}>>;
declare const CoderAppConfigProvider: ({ children, appConfig, }: CoderSettingsProviderProps) => react__default.JSX.Element;

type CoderProviderProps = ComponentProps<typeof CoderAuthProvider> & ComponentProps<typeof CoderAppConfigProvider> & {
    queryClient?: QueryClient;
};

declare const workspaceCreationModeSchema: valibot.OptionalSchema<valibot.UnionSchema<(valibot.LiteralSchema<"manual", "manual"> | valibot.LiteralSchema<"auto", "auto">)[], "manual" | "auto">, undefined, "manual" | "auto" | undefined>;
type WorkspaceCreationMode = Output<typeof workspaceCreationModeSchema>;
/**
 * Provides a cleaned and pre-processed version of all repo data that can be
 * sourced from CoderAppConfig and any entity data.
 */
type CoderWorkspacesConfig = Readonly<{
    isReadingEntityData: boolean;
    creationUrl?: string;
    templateName?: string;
    repoUrlParamKeys: readonly string[];
    mode: 'manual' | 'auto';
    params: Record<string, string | undefined>;
    repoUrl: string | undefined;
}>;
type UseCoderWorkspacesConfigOptions = Readonly<{
    readEntityData?: boolean;
}>;
declare function useCoderWorkspacesConfig({ readEntityData, }: UseCoderWorkspacesConfigOptions): CoderWorkspacesConfig;

declare const workspaceSchema: valibot.ObjectSchema<{
    id: valibot.StringSchema<string>;
    name: valibot.StringSchema<string>;
    template_icon: valibot.StringSchema<string>;
    owner_name: valibot.StringSchema<string>;
    latest_build: valibot.ObjectSchema<{
        id: valibot.StringSchema<string>;
        resources: valibot.ArraySchema<valibot.ObjectSchema<{
            id: valibot.StringSchema<string>;
            agents: valibot.OptionalSchema<valibot.ArraySchema<valibot.ObjectSchema<{
                id: valibot.StringSchema<string>;
                status: valibot.UnionSchema<(valibot.LiteralSchema<"connected", "connected"> | valibot.LiteralSchema<"connecting", "connecting"> | valibot.LiteralSchema<"disconnected", "disconnected"> | valibot.LiteralSchema<"timeout", "timeout">)[], "connected" | "connecting" | "disconnected" | "timeout">;
            }, undefined, {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }>, {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[]>, undefined, {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined>;
        }, undefined, {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }>, {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[]>;
        status: valibot.UnionSchema<(valibot.LiteralSchema<"canceled", "canceled"> | valibot.LiteralSchema<"canceling", "canceling"> | valibot.LiteralSchema<"deleted", "deleted"> | valibot.LiteralSchema<"deleting", "deleting"> | valibot.LiteralSchema<"failed", "failed"> | valibot.LiteralSchema<"pending", "pending"> | valibot.LiteralSchema<"running", "running"> | valibot.LiteralSchema<"starting", "starting"> | valibot.LiteralSchema<"stopped", "stopped"> | valibot.LiteralSchema<"stopping", "stopping">)[], "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping">;
    }, undefined, {
        id: string;
        status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
        resources: {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[];
    }>;
}, undefined, {
    id: string;
    name: string;
    template_icon: string;
    owner_name: string;
    latest_build: {
        id: string;
        status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
        resources: {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[];
    };
}>;
type Workspace = Output<typeof workspaceSchema>;

/**
 * @file Wires up all the core logic for passing values down to the
 * sub-components in the same directory.
 */

type WorkspacesQuery = UseQueryResult<readonly Workspace[]>;
type WorkspacesCardContext = Readonly<{
    queryFilter: string;
    onFilterChange: (newFilter: string) => void;
    workspacesQuery: WorkspacesQuery;
    workspacesConfig: CoderWorkspacesConfig;
    headerId: string;
}>;
type WorkspacesCardProps = Readonly<Omit<HTMLAttributes<HTMLDivElement>, 'role' | 'aria-labelledby'> & {
    queryFilter?: string;
    defaultQueryFilter?: string;
    onFilterChange?: (newFilter: string) => void;
    readEntityData?: boolean;
}>;
declare function Root(props: WorkspacesCardProps): react__default.JSX.Element;
declare function useWorkspacesCardContext(): WorkspacesCardContext;

type ReminderAccordionProps = Readonly<{
    canShowEntityReminder?: boolean;
    canShowTemplateNameReminder?: boolean;
}>;
declare function ReminderAccordion({ canShowEntityReminder, canShowTemplateNameReminder, }: ReminderAccordionProps): react__default.JSX.Element;

type QueryInput = Readonly<{
    coderQuery: string;
    workspacesConfig?: CoderWorkspacesConfig;
}>;
declare function useCoderWorkspacesQuery({ coderQuery, workspacesConfig, }: QueryInput): _tanstack_react_query.UseQueryResult<readonly {
    id: string;
    name: string;
    template_icon: string;
    owner_name: string;
    latest_build: {
        id: string;
        status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
        resources: {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[];
    };
}[], unknown>;

declare const coderPlugin: _backstage_core_plugin_api.BackstagePlugin<{
    root: _backstage_core_plugin_api.RouteRef<undefined>;
}, {}, {}>;
/**
 * All public component exports exposed by the plugin.
 *
 * Make sure that all name properties for each exported component are unique. If
 * there are conflicts, you could run into Backstage compilation issues with no
 * good error messages to help you track down the source.
 */
declare const CoderProvider: ({ children, appConfig, queryClient, }: CoderProviderProps) => react.JSX.Element;
declare const CoderAuthWrapper: ({ children, type }: Readonly<react.PropsWithChildren<{
    type: "card";
}>>) => react.JSX.Element;
declare const CoderErrorBoundary: ({ children, fallbackUi, }: {
    children?: react.ReactNode;
    fallbackUi?: react.ReactNode;
}) => react.JSX.Element;
declare const CoderWorkspacesCard: (props: {
    readonly slot?: string | undefined;
    readonly style?: react.CSSProperties | undefined;
    readonly title?: string | undefined;
    readonly id?: string | undefined;
    readonly onError?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly lang?: string | undefined;
    readonly hidden?: boolean | undefined;
    readonly readEntityData?: boolean | undefined;
    readonly color?: string | undefined;
    readonly content?: string | undefined;
    readonly translate?: "yes" | "no" | undefined;
    readonly defaultChecked?: boolean | undefined;
    readonly defaultValue?: string | number | readonly string[] | undefined;
    readonly suppressContentEditableWarning?: boolean | undefined;
    readonly suppressHydrationWarning?: boolean | undefined;
    readonly accessKey?: string | undefined;
    readonly autoFocus?: boolean | undefined;
    readonly className?: string | undefined;
    readonly contentEditable?: "inherit" | (boolean | "false" | "true") | "plaintext-only" | undefined;
    readonly contextMenu?: string | undefined;
    readonly dir?: string | undefined;
    readonly draggable?: (boolean | "false" | "true") | undefined;
    readonly nonce?: string | undefined;
    readonly spellCheck?: (boolean | "false" | "true") | undefined;
    readonly tabIndex?: number | undefined;
    readonly radioGroup?: string | undefined;
    readonly about?: string | undefined;
    readonly datatype?: string | undefined;
    readonly inlist?: any;
    readonly prefix?: string | undefined;
    readonly property?: string | undefined;
    readonly rel?: string | undefined;
    readonly resource?: string | undefined;
    readonly rev?: string | undefined;
    readonly typeof?: string | undefined;
    readonly vocab?: string | undefined;
    readonly autoCapitalize?: string | undefined;
    readonly autoCorrect?: string | undefined;
    readonly autoSave?: string | undefined;
    readonly itemProp?: string | undefined;
    readonly itemScope?: boolean | undefined;
    readonly itemType?: string | undefined;
    readonly itemID?: string | undefined;
    readonly itemRef?: string | undefined;
    readonly results?: number | undefined;
    readonly security?: string | undefined;
    readonly unselectable?: "on" | "off" | undefined;
    readonly inputMode?: "search" | "text" | "none" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
    readonly is?: string | undefined;
    readonly "aria-activedescendant"?: string | undefined;
    readonly "aria-atomic"?: (boolean | "false" | "true") | undefined;
    readonly "aria-autocomplete"?: "none" | "both" | "inline" | "list" | undefined;
    readonly "aria-braillelabel"?: string | undefined;
    readonly "aria-brailleroledescription"?: string | undefined;
    readonly "aria-busy"?: (boolean | "false" | "true") | undefined;
    readonly "aria-checked"?: boolean | "mixed" | "false" | "true" | undefined;
    readonly "aria-colcount"?: number | undefined;
    readonly "aria-colindex"?: number | undefined;
    readonly "aria-colindextext"?: string | undefined;
    readonly "aria-colspan"?: number | undefined;
    readonly "aria-controls"?: string | undefined;
    readonly "aria-current"?: boolean | "time" | "page" | "false" | "true" | "step" | "location" | "date" | undefined;
    readonly "aria-describedby"?: string | undefined;
    readonly "aria-description"?: string | undefined;
    readonly "aria-details"?: string | undefined;
    readonly "aria-disabled"?: (boolean | "false" | "true") | undefined;
    readonly "aria-dropeffect"?: "link" | "none" | "copy" | "move" | "execute" | "popup" | undefined;
    readonly "aria-errormessage"?: string | undefined;
    readonly "aria-expanded"?: (boolean | "false" | "true") | undefined;
    readonly "aria-flowto"?: string | undefined;
    readonly "aria-grabbed"?: (boolean | "false" | "true") | undefined;
    readonly "aria-haspopup"?: boolean | "dialog" | "menu" | "grid" | "listbox" | "false" | "true" | "tree" | undefined;
    readonly "aria-hidden"?: (boolean | "false" | "true") | undefined;
    readonly "aria-invalid"?: boolean | "false" | "true" | "grammar" | "spelling" | undefined;
    readonly "aria-keyshortcuts"?: string | undefined;
    readonly "aria-label"?: string | undefined;
    readonly "aria-level"?: number | undefined;
    readonly "aria-live"?: "off" | "assertive" | "polite" | undefined;
    readonly "aria-modal"?: (boolean | "false" | "true") | undefined;
    readonly "aria-multiline"?: (boolean | "false" | "true") | undefined;
    readonly "aria-multiselectable"?: (boolean | "false" | "true") | undefined;
    readonly "aria-orientation"?: "horizontal" | "vertical" | undefined;
    readonly "aria-owns"?: string | undefined;
    readonly "aria-placeholder"?: string | undefined;
    readonly "aria-posinset"?: number | undefined;
    readonly "aria-pressed"?: boolean | "mixed" | "false" | "true" | undefined;
    readonly "aria-readonly"?: (boolean | "false" | "true") | undefined;
    readonly "aria-relevant"?: "text" | "all" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    readonly "aria-required"?: (boolean | "false" | "true") | undefined;
    readonly "aria-roledescription"?: string | undefined;
    readonly "aria-rowcount"?: number | undefined;
    readonly "aria-rowindex"?: number | undefined;
    readonly "aria-rowindextext"?: string | undefined;
    readonly "aria-rowspan"?: number | undefined;
    readonly "aria-selected"?: (boolean | "false" | "true") | undefined;
    readonly "aria-setsize"?: number | undefined;
    readonly "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    readonly "aria-valuemax"?: number | undefined;
    readonly "aria-valuemin"?: number | undefined;
    readonly "aria-valuenow"?: number | undefined;
    readonly "aria-valuetext"?: string | undefined;
    readonly dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    readonly onCopy?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    readonly onCopyCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    readonly onCut?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    readonly onCutCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    readonly onPaste?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    readonly onPasteCapture?: react.ClipboardEventHandler<HTMLDivElement> | undefined;
    readonly onCompositionEnd?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    readonly onCompositionEndCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    readonly onCompositionStart?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    readonly onCompositionStartCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    readonly onCompositionUpdate?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    readonly onCompositionUpdateCapture?: react.CompositionEventHandler<HTMLDivElement> | undefined;
    readonly onFocus?: react.FocusEventHandler<HTMLDivElement> | undefined;
    readonly onFocusCapture?: react.FocusEventHandler<HTMLDivElement> | undefined;
    readonly onBlur?: react.FocusEventHandler<HTMLDivElement> | undefined;
    readonly onBlurCapture?: react.FocusEventHandler<HTMLDivElement> | undefined;
    readonly onChange?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onChangeCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onBeforeInput?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onBeforeInputCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onInput?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onInputCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onReset?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onResetCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onSubmit?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onSubmitCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onInvalid?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onInvalidCapture?: react.FormEventHandler<HTMLDivElement> | undefined;
    readonly onLoad?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onLoadCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onErrorCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onKeyDown?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    readonly onKeyDownCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    readonly onKeyPress?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    readonly onKeyPressCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    readonly onKeyUp?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    readonly onKeyUpCapture?: react.KeyboardEventHandler<HTMLDivElement> | undefined;
    readonly onAbort?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onAbortCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onCanPlay?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onCanPlayCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onCanPlayThrough?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onCanPlayThroughCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onDurationChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onDurationChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onEmptied?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onEmptiedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onEncrypted?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onEncryptedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onEnded?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onEndedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onLoadedData?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onLoadedDataCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onLoadedMetadata?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onLoadedMetadataCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onLoadStart?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onLoadStartCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onPause?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onPauseCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onPlay?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onPlayCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onPlaying?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onPlayingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onProgress?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onProgressCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onRateChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onRateChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onResize?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onResizeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onSeeked?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onSeekedCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onSeeking?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onSeekingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onStalled?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onStalledCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onSuspend?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onSuspendCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onTimeUpdate?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onTimeUpdateCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onVolumeChange?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onVolumeChangeCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onWaiting?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onWaitingCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onAuxClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onAuxClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onContextMenu?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onContextMenuCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onDoubleClick?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onDoubleClickCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onDrag?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragEnd?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragEndCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragEnter?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragEnterCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragExit?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragExitCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragLeave?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragLeaveCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragOver?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragOverCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragStart?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDragStartCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDrop?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onDropCapture?: react.DragEventHandler<HTMLDivElement> | undefined;
    readonly onMouseDown?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseDownCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseEnter?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseLeave?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseMove?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseMoveCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseOut?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseOutCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseOver?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseOverCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseUp?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onMouseUpCapture?: react.MouseEventHandler<HTMLDivElement> | undefined;
    readonly onSelect?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onSelectCapture?: react.ReactEventHandler<HTMLDivElement> | undefined;
    readonly onTouchCancel?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onTouchCancelCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onTouchEnd?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onTouchEndCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onTouchMove?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onTouchMoveCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onTouchStart?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onTouchStartCapture?: react.TouchEventHandler<HTMLDivElement> | undefined;
    readonly onPointerDown?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerDownCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerMove?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerMoveCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerUp?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerUpCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerCancel?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerCancelCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerEnter?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerEnterCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerLeave?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerLeaveCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerOver?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerOverCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerOut?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onPointerOutCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onGotPointerCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onGotPointerCaptureCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onLostPointerCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onLostPointerCaptureCapture?: react.PointerEventHandler<HTMLDivElement> | undefined;
    readonly onScroll?: react.UIEventHandler<HTMLDivElement> | undefined;
    readonly onScrollCapture?: react.UIEventHandler<HTMLDivElement> | undefined;
    readonly onWheel?: react.WheelEventHandler<HTMLDivElement> | undefined;
    readonly onWheelCapture?: react.WheelEventHandler<HTMLDivElement> | undefined;
    readonly onAnimationStart?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    readonly onAnimationStartCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    readonly onAnimationEnd?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    readonly onAnimationEndCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    readonly onAnimationIteration?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    readonly onAnimationIterationCapture?: react.AnimationEventHandler<HTMLDivElement> | undefined;
    readonly onTransitionEnd?: react.TransitionEventHandler<HTMLDivElement> | undefined;
    readonly onTransitionEndCapture?: react.TransitionEventHandler<HTMLDivElement> | undefined;
    readonly queryFilter?: string | undefined;
    readonly defaultQueryFilter?: string | undefined;
    readonly onFilterChange?: ((newFilter: string) => void) | undefined;
}) => react.JSX.Element;
declare const CoderWorkspacesCardCreateWorkspacesLink: ({ children, className, tooltipRef, target, tooltipText, tooltipProps, ...delegatedProps }: Readonly<Omit<react.AnchorHTMLAttributes<HTMLAnchorElement>, "aria-disabled"> & {
    tooltipText?: string | react.ReactElement<any, string | react.JSXElementConstructor<any>> | undefined;
    tooltipProps?: Omit<_material_ui_core.TooltipProps, "title" | "children"> | undefined;
    tooltipRef?: react.ForwardedRef<unknown> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardExtraActionsButton: ({ menuProps, buttonRef, toolTipProps, tooltipRef, children, className, onClick: outerOnClick, onClose: outerOnClose, tooltipText, ...delegatedButtonProps }: Readonly<Omit<react.ButtonHTMLAttributes<HTMLButtonElement>, "id" | "aria-controls"> & {
    onClose?: ((event: {}, reason: "backdropClick" | "escapeKeyDown") => void) | undefined;
    buttonRef?: react.ForwardedRef<HTMLButtonElement> | undefined;
    menuProps?: Readonly<Omit<_material_ui_core.MenuProps, "id" | "children" | "open" | "onClose" | "anchorEl" | "MenuListProps" | "getContentAnchorEl"> & {
        MenuListProps: Omit<_material_ui_core.MenuListProps, "aria-describedby" | "aria-labelledby">;
    }> | undefined;
    toolTipProps?: Omit<_material_ui_core.TooltipProps, "title" | "children"> | undefined;
    tooltipText?: string | undefined;
    tooltipRef?: react.ForwardedRef<unknown> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardHeaderRow: ({ actions, headerLevel, className, headerClassName, hgroupClassName, subheaderClassName, activeRepoFilteringText, headerText, fullBleedLayout, ...delegatedProps }: Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "children"> & Partial<Record<"headerClassName" | "hgroupClassName" | "subheaderClassName", string>> & {
    headerText?: string | undefined;
    headerLevel?: "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | undefined;
    actions?: react.ReactNode;
    fullBleedLayout?: boolean | undefined;
    activeRepoFilteringText?: react.ReactNode;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardRoot: typeof Root;
declare const CoderWorkspacesCardSearchBox: ({ className, labelWrapperClassName, searchInputClassName, clearButtonClassName, searchInputRef, clearButtonRef, ...delegatedProps }: Readonly<Omit<react.FieldsetHTMLAttributes<HTMLFieldSetElement>, "children" | "aria-labelledby"> & Partial<Record<"labelWrapperClassName" | "clearButtonClassName" | "searchInputClassName", string>> & {
    searchInputRef?: react.ForwardedRef<HTMLInputElement> | undefined;
    clearButtonRef?: react.ForwardedRef<HTMLButtonElement> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardWorkspacesList: ({ renderListItem, emptyState, className, listClassName, ordered, fullBleedLayout, ...delegatedProps }: Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "children"> & {
    emptyState?: react.ReactNode;
    ordered?: boolean | undefined;
    listClassName?: string | undefined;
    fullBleedLayout?: boolean | undefined;
    renderListItem?: ((input: Readonly<{
        workspace: {
            id: string;
            name: string;
            template_icon: string;
            owner_name: string;
            latest_build: {
                id: string;
                status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
                resources: {
                    id: string;
                    agents?: {
                        id: string;
                        status: "connected" | "connecting" | "disconnected" | "timeout";
                    }[] | undefined;
                }[];
            };
        };
        index: number;
        workspaces: readonly {
            id: string;
            name: string;
            template_icon: string;
            owner_name: string;
            latest_build: {
                id: string;
                status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
                resources: {
                    id: string;
                    agents?: {
                        id: string;
                        status: "connected" | "connecting" | "disconnected" | "timeout";
                    }[] | undefined;
                }[];
            };
        }[];
    }>) => react.ReactNode) | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardWorkspacesListIcon: ({ src, workspaceName, className, imageClassName, imageRef, ...delegatedProps }: Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "children" | "aria-hidden"> & {
    src: string;
    workspaceName: string;
    imageClassName?: string | undefined;
    imageRef?: react.ForwardedRef<HTMLImageElement> | undefined;
}>) => react.JSX.Element;
declare const CoderWorkspacesCardWorkspacesListItem: ({ workspace, className, listFlexRowClassName, linkClassName, onlineStatusContainerClassName, onlineStatusLightClassName, buttonClassName, onClick: outerOnClick, onAuxClick: outerOnAuxClick, onKeyDown: outerOnKeyDown, ...delegatedProps }: Readonly<Omit<react.LiHTMLAttributes<HTMLLIElement>, "children"> & Partial<Record<"buttonClassName" | "linkClassName" | "listFlexRowClassName" | "onlineStatusContainerClassName" | "onlineStatusLightClassName", string>> & {
    workspace: {
        id: string;
        name: string;
        template_icon: string;
        owner_name: string;
        latest_build: {
            id: string;
            status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
            resources: {
                id: string;
                agents?: {
                    id: string;
                    status: "connected" | "connecting" | "disconnected" | "timeout";
                }[] | undefined;
            }[];
        };
    };
}>) => react.JSX.Element;
declare const CoderWorkspacesReminderAccordion: typeof ReminderAccordion;

export { CoderAppConfig, CoderAuthWrapper, CoderErrorBoundary, CoderProvider, CoderWorkspacesCard, CoderWorkspacesCardCreateWorkspacesLink, CoderWorkspacesCardExtraActionsButton, CoderWorkspacesCardHeaderRow, CoderWorkspacesCardRoot, CoderWorkspacesCardSearchBox, CoderWorkspacesCardWorkspacesList, CoderWorkspacesCardWorkspacesListIcon, CoderWorkspacesCardWorkspacesListItem, CoderWorkspacesReminderAccordion, coderPlugin, useCoderWorkspacesConfig, useCoderWorkspacesQuery, useWorkspacesCardContext };
